#' Digital Elevation Model of Zlatibor region in Serbia.
#'
#' A dataset containing the mean an example Digital Elevation Model.
#'
#' @docType data
#' 
#' @format a SpatialGridDataFrame with 15000 rows and 1 variable:
#' \describe{
#' \item{Elevation}{Digital Elevation Model, in meters}
#' }
#' 
#' @usage data(dem30m)
#' 
#' @source The Zlatibor dataset was kindly provided by Prof. Branislav Bajat
#'  from the University of Belgrade, Serbia.
#'  
#' @name dem30m
NULL